==> occam-lexers-0.1.16.tgz: package/es6/florence/nonSignificantTokens.js <==
'use strict';

var util = require('../util'),
    EndOfLineToken = require('./token/endOfLine'),
    EndOfCommentToken = require('./token/endOfComment'),
    StartOfCommentToken = require('./token/startOfComment'),
    MiddleOfCommentToken = require('./token/middleOfComment'),
    SignificantContentToken = require('../common/token/significantContent'),
    WhitespaceToken = require('../common/token/whitespace');

class NonSignificantTokens {
  static pass(content, context, line) {
    var tokens = [],
        remainingContent,
        commentToken,
        commentTokenLength;

    while (content !== '') {
      var contentLength = content.length,
          inComment = context.isInComment();

      var startOfCommentTokenPosition = StartOfCommentToken.position(content),
          endOfCommentTokenPosition = EndOfCommentToken.position(content);

      if (!inComment) {
        if (startOfCommentTokenPosition === 0) {
          context.setInComment(true);

          commentToken = StartOfCommentToken.fromContent(content, line);

          commentTokenLength = commentToken.getLength();

          remainingContent = content.substring(commentTokenLength);

          content = remainingContent;

          tokens.push(commentToken);

          continue;
        }
      } else {
        var previousCommentToken = tokens.pop(),
            middleOfCommentTokenLength = util.minBarMinusOne(endOfCommentTokenPosition, contentLength);

        if (false) {

        } else if (endOfCommentTokenPosition === 0) {
          context.setInComment(false);

          commentToken = EndOfCommentToken.fromContent(content, line);

          commentTokenLength = commentToken.getLength();

          remainingContent = content.substring(commentTokenLength);
        } else {
          remainingContent = content.substring(middleOfCommentTokenLength);

          content = content.substring(0, middleOfCommentTokenLength);

          commentToken = MiddleOfCommentToken.fromContent(content, line);
        }

        commentToken = (previousCommentToken === undefined) ?
                         commentToken :
                           previousCommentToken.merge(commentToken);

        content = remainingContent;

        tokens.push(commentToken);

        continue;
      }

      var whitespaceTokenPosition = WhitespaceToken.position(content);

      if (whitespaceTokenPosition === 0) {
        var whitespaceToken = WhitespaceToken.fromContent(content, line),
            whitespaceTokenLength = whitespaceToken.getLength();

        content = content.substring(whitespaceTokenLength);

        tokens.push(whitespaceToken);

        continue;
      }

      var significantContentTokenLength = util.minBarMinusOne(startOfCommentTokenPosition, whitespaceTokenPosition, contentLength);

      remainingContent = content.substring(significantContentTokenLength);

      content = content.substring(0, significantContentTokenLength);

      var significantContentToken = SignificantContentToken.fromContent(content);

      content = remainingContent;

      tokens.push(significantContentToken);

      continue;
    }
    
    var endOfLineToken = EndOfLineToken.fromNothing(line);
    
    tokens.push(endOfLineToken);

    return tokens;
  }
}

module.exports = NonSignificantTokens;

==> occam-lexers-0.1.25.tgz: package/es6/florence/nonSignificantTokens.js <==
'use strict';

var util = require('../util'),
    EndOfLineToken = require('./token/endOfLine'),
    WhitespaceToken = require('../common/token/whitespace'),
    EndOfCommentToken = require('./token/endOfComment'),
    StartOfCommentToken = require('./token/startOfComment'),
    MiddleOfCommentToken = require('./token/middleOfComment');

class NonSignificantTokens {
  static pass(content, context, line) {
    var nonSignificantTokensOrSignificantContent = [],
        remainingContent,
        commentToken,
        commentTokenLength;

    while (content !== '') {
      var contentLength = content.length,
          inComment = context.isInComment();

      var startOfCommentTokenPosition = StartOfCommentToken.position(content),
          endOfCommentTokenPosition = EndOfCommentToken.position(content);

      if (!inComment) {
        if (startOfCommentTokenPosition === 0) {
          context.setInComment(true);

          commentToken = StartOfCommentToken.fromContent(content, line);

          commentTokenLength = commentToken.getLength();

          remainingContent = content.substring(commentTokenLength);

          content = remainingContent;

          nonSignificantTokensOrSignificantContent.push(commentToken);

          continue;
        }
      } else {
        var previousCommentToken = nonSignificantTokensOrSignificantContent.pop(),
            middleOfCommentTokenLength = util.minBarMinusOne(endOfCommentTokenPosition, contentLength);

        if (false) {

        } else if (endOfCommentTokenPosition === 0) {
          context.setInComment(false);

          commentToken = EndOfCommentToken.fromContent(content, line);

          commentTokenLength = commentToken.getLength();

          remainingContent = content.substring(commentTokenLength);
        } else {
          remainingContent = content.substring(middleOfCommentTokenLength);

          content = content.substring(0, middleOfCommentTokenLength);

          commentToken = MiddleOfCommentToken.fromContent(content, line);
        }

        commentToken = (previousCommentToken === undefined) ?
                         commentToken :
                           previousCommentToken.merge(commentToken);

        content = remainingContent;

        nonSignificantTokensOrSignificantContent.push(commentToken);

        continue;
      }

      var whitespaceTokenPosition = WhitespaceToken.position(content);

      if (whitespaceTokenPosition === 0) {
        var whitespaceToken = WhitespaceToken.fromContent(content, line),
            whitespaceTokenLength = whitespaceToken.getLength();

        content = content.substring(whitespaceTokenLength);

        nonSignificantTokensOrSignificantContent.push(whitespaceToken);

        continue;
      }

      var significantContentLength = util.minBarMinusOne(startOfCommentTokenPosition, whitespaceTokenPosition, contentLength),
          significantContent = content.substring(0, significantContentLength); 

      remainingContent = content.substring(significantContentLength);

      content = remainingContent;

      nonSignificantTokensOrSignificantContent.push(significantContent);

      continue;
    }
    
    var endOfLineToken = EndOfLineToken.fromNothing(line);
    
    nonSignificantTokensOrSignificantContent.push(endOfLineToken);

    return nonSignificantTokensOrSignificantContent;
  }
}

module.exports = NonSignificantTokens;
